@@ -467,6 +467,7 @@ class Mesh:
                                     "name": device.name,
                                     "ip": adapter.get("ip"),
                                     "type": adapter.get("type"),
+                                    "guest_network": adapter.get("guest_network")
                                 })
                             if node.parent_ip and not parent_name:
                                 if node.parent_ip == adapter.get("ip"):
@@ -476,7 +477,7 @@ class Mesh:
                     # endregion
                 elif node.__class__.__name__.lower() == "device":
                     # region #-- calculate parent name for devices --#
-                    attrib_connections = getattr(node, "_Device__attributes", {}).get("connections", [])
+                    attrib_connections = getattr(node, "_attribs", {}).get("connections", [])
                     parent: Union[str, None] = None
                     for conn in attrib_connections:
                         if conn.get("parentDeviceID", ""):
@@ -506,7 +507,7 @@ class Mesh:
                                     if mac in rule.get("macAddresses", []):
                                         pc_schedule.append(rule)
                                         break
-                    getattr(node, "_Device__attributes", {})["parental_controls"] = pc_schedule
+                    getattr(node, "_attribs", {})["parental_controls"] = pc_schedule
                     # endregion
             # endregion
 
